import { useEffect, useState } from 'react';
import { withConfiguration } from '@pega/cosmos-react-core';
import {
  ResponsiveContainer,
  LineChart,
  CartesianGrid,
  XAxis,
  YAxis,
  Line,
  Tooltip,
  Legend
} from 'recharts';
import type { PConnFieldProps } from './PConnProps';
import AxisLabel from './components/AxisLabel';
import StyledAreteansExtensionsLineChartsWrapper from './styles';

// interface for props
interface AreteansExtensionsLineChartsProps extends PConnFieldProps {
  // If any, enter additional props that only exist on TextInput here
  autoPrependXLabelVal?: string;
  autoAppendXLabelVal?: string;
  showTickLinesForXAxis?: boolean;
}

// props passed in combination of props from property panel (config.json) and run time props from Constellation
// any default values in config.pros should be set in defaultProps at bottom of this file
function AreteansExtensionsLineCharts(props: AreteansExtensionsLineChartsProps) {
  const {
    chartTitle,
    chartContainerWidthVal = 200,
    chartContainerWidthType = '%',
    chartContainerHeightVal = 600,
    chartContainerHeightType = 'px',
    chartWidthVal = 800,
    chartHeightVal = 500,
    datasource,
    datasourceParam,
    datasourceParamValue,
    dataKeyForXAxis,
    xAxisLabel,
    yAxisLabel,
    xAxisVisibility = true,
    yAxisVisibility = true,
    showXAxisGridLabels = true,
    showYAxisGridLabels = true,
    autoPrependXLabelVal,
    autoAppendXLabelVal,
    showTickLinesForXAxis = true,

    showHorizontalGridLines = true,
    showVerticalGridLines,
    gridOpacity,
    primarySeriesColumnKey,
    primarySeriesColumnColor,
    secondarySeriesColumnKey,
    secondarySeriesColumnColor,
    getPConnect
  } = props;
  console.log(props);

  const [data, setData] = useState<Array<any>>([]);

  console.log(data);

  const formatAxisLabels = (str: any) => {
    return autoPrependXLabelVal + str + autoAppendXLabelVal;
  };

  const context = getPConnect().getContextName();
  // const payload = useMemo(() => {
  //   return {
  //     dataViewParameters: {
  //       [datasourceParam]: datasourceParamValue
  //     },
  //     query: {
  //       distinctResultsOnly: false,
  //       filter: {
  //         filterConditions: {
  //           F1: {
  //             comparator: 'EQ',
  //             ignoreCase: false,
  //             lhs: {
  //               field: datasourceParam
  //             },
  //             rhs: {
  //               value: datasourceParamValue
  //             }
  //           }
  //         },
  //         logic: 'F1'
  //       },
  //       select: [
  //         {
  //           field: datasourceParam
  //         },
  //         {
  //           field: dataKeyForXAxis
  //         },
  //         {
  //           field: primarySeriesColumnKey
  //         }
  //       ]
  //     }
  //   };
  // }, [dataKeyForXAxis, datasourceParam, datasourceParamValue, primarySeriesColumnKey]);

  useEffect(() => {
    (window as any).PCore.getDataApiUtils()
      .getData(datasource, {}, context)
      .then((response: any) => {
        console.log(response);
        if (response.data !== null) {
          setData(
            response.data.data.map((dataItem: any) => {
              return {
                [dataKeyForXAxis]: dataItem[dataKeyForXAxis],
                [primarySeriesColumnKey]: dataItem[primarySeriesColumnKey],
                [secondarySeriesColumnKey]: dataItem[secondarySeriesColumnKey]
              };
            })
          );
        }
      });
  }, [
    context,
    dataKeyForXAxis,
    datasource,
    datasourceParam,
    datasourceParamValue,

    primarySeriesColumnKey,
    secondarySeriesColumnKey
  ]);

  return (
    <StyledAreteansExtensionsLineChartsWrapper>
      <h2>{chartTitle}</h2>
      <ResponsiveContainer
        width={
          chartContainerWidthType === '%' ? `${chartContainerWidthVal}%` : chartContainerWidthVal
        }
        height={
          chartContainerHeightType === '%' ? `${chartContainerHeightVal}%` : chartContainerHeightVal
        }
      >
        <LineChart width={chartWidthVal} height={chartHeightVal} data={data}>
          <CartesianGrid
            horizontal={showHorizontalGridLines}
            vertical={showVerticalGridLines}
            opacity={gridOpacity * 0.01}
          />
          <XAxis
            dataKey={dataKeyForXAxis}
            axisLine={xAxisVisibility}
            tick={showXAxisGridLabels}
            tickLine={showTickLinesForXAxis}
            tickFormatter={(str: any) =>
              autoAppendXLabelVal || autoPrependXLabelVal ? formatAxisLabels(str) : str
            }
          />
          <YAxis
            dataKey={primarySeriesColumnKey}
            axisLine={yAxisVisibility}
            tick={showYAxisGridLabels}
          />
          <Tooltip />
          <Legend />
          <Line dataKey={primarySeriesColumnKey} stroke={primarySeriesColumnColor} />

          {secondarySeriesColumnKey !== '' && (
            <Line dataKey={secondarySeriesColumnKey} stroke={secondarySeriesColumnColor} />
          )}
        </LineChart>
      </ResponsiveContainer>
      <AxisLabel type='horizontal'>{xAxisLabel}</AxisLabel>
      <AxisLabel type='vertical'>{yAxisLabel}</AxisLabel>
    </StyledAreteansExtensionsLineChartsWrapper>
  );
}

export default withConfiguration(AreteansExtensionsLineCharts);
